library(ggplot2)
library(vegan) 
library(MASS)
library("EcoSimR")
library("devtools")

library(dplyr) 
library(ade4)
library(ape)
library(FD)
library(geometry)
library(reshape)
library(scales)
library(reshape2)

library(spaa)


library("pairwiseAdonis")

#preys classificated by family
fam<-read.csv("batoid_diet.csv", header=TRUE, sep=";", dec=",", row.names=1)
sp.fam<- fam$sp #rays' species object
sp.fam<- as.factor(sp.fam)
fam<- fam[, c(1:47)] #removing the  rays species column

###hellinger transformation#########################
fam.h<- decostand(fam, "hellinger")

########PERMANOVA hellinger###########
dist.fam.h<-vegdist(fam.h, na.rm=TRUE)
#Dissimilarity analisis of prey items of four rays species 
permanova.fam.h <- adonis2(dist.fam.h ~ sp.fam, by=NULL)
permanova.fam.h #p=0,001 R?=0.114

#dispersion test
perm.fam.h<- betadisper(dist.fam.h, group = sp.fam)
permutest(perm.fam.h, pairwise = TRUE, permutations = 999) #whitout overdispersion
plot(perm.fam.h)
boxplot(perm.fam.h)
plot(TukeyHSD(perm.fam.h))


par.h<- pairwise.adonis(dist.fam.h, factors=sp.fam)
par.h #dall the species shows significant difference


################SIMPER hellinger################
#percentage of dissimilarity between the rays' prey items 
simp.h<-  with(fam.h, simper(fam.h, sp.fam, permutations = 9999, ordered=TRUE))
summary(simp.h)
meandist(dist.fam.h)


#################################NMDS###########################################


#######NMDS hellinger################
nmds.fam.h <- metaMDS(fam.h, distance = "bray", autotransform = FALSE)
nmds.fam.h$stress #0.125

plot(nmds.fam.h) 

dev.new(title = "Overlap between four species of batoids",
        width = 11,
        height = 8,
        noRStudioGD = TRUE
)

ordiplot(nmds.fam.h, type = "n")
orditorp(nmds.fam.h, display = "sites", labels = F, 
         pch = c(16, 8, 17, 11) [as.numeric(sp.fam)], 
         col = c("blue", "orange", "black", "green") [as.numeric(sp.fam)],
         cex = 1)

ordiellipse(nmds.fam.h, groups = sp.fam, draw = "polygon", lty = 1, 
            border = c("blue", "orange", "black", "green") )

legend("topleft", legend = c(levels(sp.fam)),
       pch = c(16, 8, 17, 11), 
       col = c("blue", "orange", "black", "green"), bty = "n", cex = 1) # displays symbol and colour legend
legend("topright", "stress = 0.125", bty = "n", cex = 1)

###############################################################################
###############PIANKAS OVERLAP ANALYSIS 

pi.fam<- read.table("pianka_ecosim_fam.csv", header = TRUE, sep = ";", dec = ",", 
                    row.names = 1)

##OBJECTS WITH DIET BIOMASS between two species
dr<-pi.fam[c(1,3),] #Dasyatis hypostigma and Rioraja agassizii
ds<-pi.fam[c(1,4),]#D. hypostigma ans Sympeterygia bonapartii
dp<-pi.fam[c(1:2),]#D. hypostigma and Pseudobatos horkelii
rs<-pi.fam[c(3,4),]#R. agassizii and S. bonapartii
rp<-pi.fam[c(3,2),]#R. agassizii and P. horkelii
ps<-pi.fam[c(2,4),]#P. horkwlii and S. bonapartii


#overlap between the four species, using Piankas metrics
warbMod1 <- niche_null_model(pi.fam,nReps=1000)
plot(warbMod1)
plot(warbMod1,type="niche")
summary(warbMod1) 

#Dasiatys hypostimga and Rioraja agassizii overlap
warbMod2<- niche_null_model(dr,nReps=1000)
plot(warbMod2)
plot(warbMod2,type="niche") 
summary(warbMod2) 

#D. hypostigma and S. bonapartii overlap
warbMod3 <- niche_null_model(ds,nReps=1000)
plot(warbMod3)
plot(warbMod3,type="niche") 
summary(warbMod3) 

#D. hypostigma and Pseudobatos horkelii overlap
warbMod4 <- niche_null_model(dp,nReps=1000)
plot(warbMod4)
plot(warbMod4,type="niche") 
summary(warbMod4) 

#R. agassizii and S. bonapartii overlap
warbMod5 <- niche_null_model(rs,nReps=1000)
plot(warbMod5)
plot(warbMod5,type="niche") 
summary(warbMod5) 

#R. agassizii and P.horkelii overlap
warbMod6 <- niche_null_model(rp,nReps=1000)
plot(warbMod6)
plot(warbMod6,type="niche")
summary(warbMod6) 

#P. horkelii and S. bonapartii overlap
warbMod7 <- niche_null_model(ps,nReps=1000)
plot(warbMod7)
plot(warbMod7,type="niche") 
summary(warbMod7) 

#################################################################


